@@ -11,7 +11,7 @@ use strict;
 use warnings;
 use base qw(Net::Plazes::Base);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 __PACKAGE__->mk_accessors(fields());
 __PACKAGE__->has_many();
@@ -29,7 +29,7 @@ __END__
 
 =head1 NAME
 
-Net::Plazes::Plaze
+Net::Plazes::Plaze - representation of remote resource http://plazes.net/plazes(.*)
 
 =head1 VERSION
 
@@ -47,6 +47,40 @@ $Revision$
 
  my @aFields = $oObj->fields();
 
+Accessors are:
+
+=over
+
+=item id
+
+=item address
+
+=item category
+
+=item city
+
+=item country_code
+
+=item created_at
+
+=item name
+
+=item state
+
+=item timezone
+
+=item updated_at
+
+=item zip_code
+
+=item latitude
+
+=item longitude
+
+=item country
+
+=back
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
